Base class for coordinate systems. A coord receives positions already normalized to [0, 1] by the scales and returns (possibly transformed) normalized positions. Cartesian is the identity; polar / flipped / 3D coords will override this seam without touching scales or geoms.

Coord(name = character(0))

Arguments

name

Human-readable coord name.

Value

An S7 object of class Coord, the base class for coordinate systems.