Methods receive values, a named list of evaluated aesthetic vectors, and return a named list of (possibly transformed) aesthetic vectors.

compute_stat(stat, ...)

Arguments

stat

A Stat subclass instance.

...

Method arguments; all methods take values (named list of evaluated aesthetic vectors).

Value

Named list of (possibly transformed) aesthetic vectors.