Draws nothing. Useful to establish scales without showing data, or as a placeholder in code that conditionally adds a layer.

geom_blank(mapping = NULL, data = NULL)

Arguments

mapping, data

Standard layer overrides.

Value

A Layer to add with +.

Examples

ggnext(cars, aes(speed, dist)) + geom_blank()
#> <ggnext plot>
#>   data:  50 x 2
#>   aes:   x = speed, y = dist
#>   layers: 1 
#>   coord: cartesian
#>   mode:  static