Percent change from baseline over time, one trajectory per subject, with the +20% (progression) and -30% (response) RECIST thresholds marked. Distinct from geom_radar(), which is a multivariate star chart.

geom_spider_response(
  mapping = NULL,
  data = NULL,
  thresholds = TRUE,
  linewidth = NULL,
  points = TRUE
)

Arguments

mapping, data

Standard layer overrides. Map time to x, percent change to y, and the subject to group (or color).

thresholds

Draw the RECIST +20% / -30% reference lines.

linewidth

Line width.

points

Draw a marker at each visit.

Value

A Layer to add with +.

Examples

d <- data.frame(
  month = rep(c(0, 2, 4, 6), 3),
  pct = c(0, -20, -35, -40, 0, 10, 25, 40, 0, -5, -10, -8),
  subject = rep(c("S1", "S2", "S3"), each = 4)
)
ggnext(d, aes(month, pct, color = subject)) + geom_spider_response()
#> <ggnext plot>
#>   data:  12 x 3
#>   aes:   x = month, y = pct, color = subject
#>   layers: 1 
#>   coord: cartesian
#>   mode:  static