R/theme.R
theme_ggnext.Rd
Light background with a softly tinted panel and white gridlines.
theme_ggnext()
A Theme to add to a plot with +.
+
p <- ggnext(cars, aes(speed, dist)) + geom_point() + theme_dark()