A scatter where the point area encodes how many observations share that position — the fix for a scatter of rounded or discrete values where overplotting hides the mass.
geom_count(mapping = NULL, data = NULL, color = NULL, alpha = NULL)A Layer to add with +.
d <- data.frame(x = c(1, 1, 1, 2, 2, 3), y = c(1, 1, 2, 2, 2, 3))
ggnext(d, aes(x, y)) + geom_count()
#> <ggnext plot>
#> data: 6 x 2
#> aes: x = x, y = y
#> layers: 1
#> coord: cartesian
#> mode: static