A quadratic curve between two points, for annotation leaders and relationship diagrams where a straight segment would overlap the data.
geom_curve(
mapping = NULL,
data = NULL,
curvature = NULL,
color = NULL,
linewidth = NULL,
alpha = NULL
)A Layer to add with +.
d <- data.frame(x = 1, y = 1, xe = 3, ye = 3)
ggnext(d, aes(x, y, xend = xe, yend = ye)) + geom_curve()
#> <ggnext plot>
#> data: 1 x 4
#> aes: x = x, y = y, xend = xe, yend = ye
#> layers: 1
#> coord: cartesian
#> mode: static