Map data values through a trained scale onto [0, 1]
scale_map(scale, ...)A trained Scale subclass instance.
Method arguments; all methods take values (numeric data
vector) and optionally expand, a padded (expanded) domain to map
against instead of the trained domain, as produced during the plot
build.
Numeric vector of normalized positions.